@@ -30,7 +30,7 @@ FK on L<Interchange6::Schema::Result::NavigationAttribute/navigation_attributes_
 =cut
 
 column navigation_attributes_id =>
-  { data_type => "integer", is_foreign_key => 1 };
+  { data_type => "integer" };
 
 =head2 attribute_values_id
 
@@ -39,7 +39,7 @@ FK on L<Interchange6::Schema::Result::AttributeValue/attribute_values_id>.
 =cut
 
 column attribute_values_id =>
-  { data_type => "integer", is_foreign_key => 1 };
+  { data_type => "integer" };
 
 =head1 RELATIONS
 
