@@ -16,10 +16,11 @@ Provides extra accessor methods for L<Interchange6::Schema::Result::Tax>
 
 use strict;
 use warnings;
+use mro 'c3';
 
 use DateTime;
 
-use base 'DBIx::Class::ResultSet';
+use parent 'Interchange6::Schema::ResultSet';
 
 =head1 METHODS
 
