@@ -14,7 +14,7 @@ test 'simple message tests' => sub {
 
     my $schema = $self->ic6s_schema;
 
-    my ( $data, $result );
+    my ( $data, $result, $rset );
 
     my $rset_message = $schema->resultset('Message');
 
@@ -43,6 +43,18 @@ test 'simple message tests' => sub {
     lives_ok( sub { $result->delete }, "delete message" );
     cmp_ok( $rset_message->count, '==', 0, "We have zero messages" );
 
+    throws_ok {
+        $rset_message->create(
+            {
+                content          => "the content",
+                title            => "the title",
+                message_types_id => 8768768
+            }
+          )
+    }
+    qr/message_types_id value does not exist in MessageType/,
+      "insert with non-existant message_types_id fails";
+
     lives_ok( sub { $result = $schema->resultset('MessageType')->find({
                     name => 'blog_post' })}, "find blog_post MessageType" );
 
@@ -104,10 +116,14 @@ test 'simple message tests' => sub {
 
     cmp_ok( $result->author->id, '==', $author->id, "has correct author" );
     cmp_ok( $result->author->email, 'eq', $author->email, "has correct author" );
+    cmp_ok( $result->message_type->name, 'eq', 'blog_post', "is a blog_post" );
 
     cmp_ok( $result->approved_by->id,
         '==', $approver->id, "has correct approver" );
 
+    my $blog_posts = $result->author->blog_posts;
+    cmp_ok $blog_posts->count, '==', 1, "author->blog_posts->count == 1";
+
     my $dt = DateTime->now;
     cmp_ok( $result->created,       '<=', $dt, "created is <= now" );
     cmp_ok( $result->last_modified, '<=', $dt, "last_modified is <= now" );
@@ -127,6 +143,50 @@ test 'simple message tests' => sub {
     );
 
     lives_ok( sub { $result->delete }, "delete message" );
+
+    $data = {
+        content => "the content",
+        type    => "blog_post",
+        message_types_id =>
+          $self->message_types->find( { name => "order_comment" } )->id,
+    };
+    throws_ok { $result = $rset_message->create($data) }
+    qr/mismatched type settings/, "fail mismatched type settings";
+
+    $data = {
+        content => "the content",
+        type    => "XX_no_such_type",
+    };
+    throws_ok { $result = $rset_message->create($data) }
+    qr/MessageType.+does not exist/, "fail bad type";
+
+    $data = {
+        content => "the content",
+        type    => "blog_post",
+        message_types_id =>
+          $self->message_types->find( { name => "order_comment" } )->id,
+    };
+    throws_ok { $result = $rset_message->create($data) }
+    qr/mismatched type settings/, "fail mismatched type settings";
+
+    $data = {
+        content => "the content",
+        type    => "blog_post",
+        message_types_id =>
+          $self->message_types->find( { name => "blog_post" } )->id,
+    };
+    lives_ok { $result = $rset_message->create($data) }
+    "Create message with match type and message_types_id";
+
+    lives_ok { $result->delete } "delete message";
+
+    $data = {
+        content => "the content",
+        type    => "XX_no_such_type",
+    };
+    throws_ok { $result = $rset_message->create($data) }
+    qr/MessageType.+does not exist/, "fail bad type";
+
     cmp_ok( $rset_message->count, '==', 0, "We have zero messages" );
 };
 
@@ -196,6 +256,27 @@ test 'order comments tests' => sub {
 
     cmp_ok( $schema->resultset('Order')->count, "==", 1, "We have 1 order" );
 
+    throws_ok { $order->set_comments }
+    qr/set_comments needs a list of objects or hashrefs/,
+      "Fail set_comments with no args";
+
+    lives_ok {
+        $result = $schema->resultset('Message')->create(
+            {
+                type    => "order_comment",
+                title   => "some other title",
+                content => "some comment as well"
+            }
+          )
+    }
+    "Create a Message with type order_comment";
+
+    lives_ok( sub { $order->set_comments($result) },
+        "Add comment to order using set_comments(object)" );
+
+    cmp_ok( $schema->resultset('Order')->count, "==", 1, "We have 1 order" );
+    cmp_ok( $rset_message->count, '==', 1, "1 Message row" );
+
     $data = {
         title           => "Initial order comment",
         content         => "Please deliver to my neighbour if I am not at home",
@@ -205,16 +286,32 @@ test 'order comments tests' => sub {
     lives_ok( sub { $order->set_comments($data) },
         "Add comment to order using set_comments" );
 
+    $data = [
+        {
+            title   => "Initial order comment",
+            content => "Please deliver to my neighbour if I am not at home",
+            author_users_id => $user->id,
+        },
+        {
+            title   => "Anoter order comment",
+            content => "otherwise the dog will eat it",
+            author_users_id => $user->id,
+        },
+    ];
+
+    lives_ok( sub { $order->set_comments($data) },
+        "Add comment to order using set_comments(array_reference)" );
+
     cmp_ok( $schema->resultset('Order')->count, "==", 1, "We have 1 order" );
-    cmp_ok( $rset_message->count, '==', 1, "1 Message row" );
-    cmp_ok( $rset_order_comment->count, '==', 1, "1 OrderComment row" );
+    cmp_ok( $rset_message->count, '==', 2, "2 Message rows" );
+    cmp_ok( $rset_order_comment->count, '==', 2, "2 OrderComment rows" );
 
     lives_ok( sub { $order->set_comments($data) },
         "repeat set_comments" );
 
     cmp_ok( $schema->resultset('Order')->count, "==", 1, "We have 1 order" );
-    cmp_ok( $rset_message->count, '==', 1, "1 Message row" );
-    cmp_ok( $rset_order_comment->count, '==', 1, "1 OrderComment row" );
+    cmp_ok( $rset_message->count, '==', 2, "2 Message rows" );
+    cmp_ok( $rset_order_comment->count, '==', 2, "2 OrderComment rows" );
 
     lives_ok(
         sub {
@@ -231,7 +328,7 @@ test 'order comments tests' => sub {
     lives_ok( sub { $rset = $order->search_related("order_comments") },
         "Search for comments on order" );
 
-    cmp_ok( $rset->count, "==", 2, "Found 2 order comments" );
+    cmp_ok( $rset->count, "==", 3, "Found 3 order comments" );
 
     lives_ok( sub { $result = $schema->resultset('MessageType')->find({
                     name => 'order_comment' })}, "find order_comment MessageType" );
@@ -245,7 +342,7 @@ test 'order comments tests' => sub {
     lives_ok( sub { $rset = $order->search_related("order_comments") },
         "Search for comments on order" );
 
-    cmp_ok( $rset->count, "==", 2, "Found 2 order comments" );
+    cmp_ok( $rset->count, "==", 3, "Found 3 order comments" );
 
     throws_ok(
         sub {
@@ -257,6 +354,48 @@ test 'order comments tests' => sub {
 
     lives_ok( sub { $result->update({ active => 1 }) }, "change to active" );
 
+    throws_ok { $order->add_to_comments }
+    qr/add_to_comments needs an object or hashref/,
+      "add_to_comments fails with no args";
+
+    lives_ok {
+        $order->add_to_comments(
+            title   => "order response",
+            content => "frizzzzz"
+          )
+    }
+    "add_to_comments args are array";
+
+    lives_ok {
+        $result = $schema->resultset('Message')->create(
+            {
+                type    => "order_comment",
+                title   => "some other title",
+                content => "some comment as well"
+            }
+          )
+    }
+    "Create a Message with type order_comment";
+
+    lives_ok { $order->add_to_comments($result) }
+    "Add message object to order using add_to_comments";
+
+    lives_ok {
+        $result = $schema->resultset('Message')->create(
+            {
+                type    => "blog_post",
+                title   => "some other title",
+                content => "some comment as well"
+            }
+          )
+    }
+    "Create a Message with type blog_post";
+
+    throws_ok { $order->add_to_comments($result) } qr/cannot add message type/,
+    "Fail to add message object to order using add_to_comments";
+
+    lives_ok { $result->delete } "delete blog_post";
+
     lives_ok( sub { $order->delete }, "Delete order" );
 
     cmp_ok( $schema->resultset("Order")->count, "==", 0, "Zero orders" );
@@ -345,7 +484,7 @@ test 'order comments tests' => sub {
 test 'product reviews tests' => sub {
     my $self = shift;
 
-    my ( $product, $variant, $author, $approver, $rset, $result );
+    my ( $message, $product, $variant, $author, $approver, $rset, $result );
 
     my $rset_message = $self->ic6s_schema->resultset('Message');
 
@@ -399,29 +538,35 @@ test 'product reviews tests' => sub {
         "Add review to parent product with set_reviews"
     );
 
+    cmp_ok( $product->product_reviews->count,
+        '==', 1, "parent has 1 product_reviews" );
+    cmp_ok( $variant->product_reviews->count, '==', 1,
+        "variant has 1 product_reviews" );
     cmp_ok( $product->reviews->count,  '==', 1, "parent has 1 reviews" );
     cmp_ok( $variant->reviews->count,  '==', 1, "variant has 1 reviews" );
-    cmp_ok( $product->_reviews->count, '==', 1, "parent has 1 _reviews" );
-    cmp_ok( $variant->_reviews->count, '==', 0, "variant has 0 _reviews" );
+    cmp_ok( $product->messages->count, '==', 1, "parent has 1 messages" );
+    cmp_ok( $variant->messages->count, '==', 0, "variant has 0 messages" );
 
     cmp_ok( $self->ic6s_schema->resultset('Message')->count,
         '==', 2, "2 Message rows" );
 
-    cmp_ok( $self->ic6s_schema->resultset('ProductReview')->count,
-        '==', 1, "1 ProductReview row" );
+    cmp_ok( $self->ic6s_schema->resultset('ProductMessage')->count,
+        '==', 1, "1 ProductMessage row" );
 
     lives_ok(
         sub {
             $result = $product->set_reviews(
-                {
-                    title           => "massive bananas",
-                    content         => "Love them",
-                    author_users_id => $author->id
-                },
-                {
-                    title   => "cool as ice",
-                    content => "cool blue",
-                }
+                [
+                    {
+                        title           => "massive bananas",
+                        content         => "Love them",
+                        author_users_id => $author->id
+                    },
+                    {
+                        title   => "cool as ice",
+                        content => "cool blue",
+                    },
+                ]
             );
         },
         "repeat set_reviews with 2 reviews"
@@ -429,15 +574,27 @@ test 'product reviews tests' => sub {
 
     cmp_ok( $product->reviews->count,  '==', 2, "parent has 2 reviews" );
     cmp_ok( $variant->reviews->count,  '==', 2, "variant has 2 reviews" );
-    cmp_ok( $product->_reviews->count, '==', 2, "parent has 2 _reviews" );
-    cmp_ok( $variant->_reviews->count, '==', 0, "variant has 0 _reviews" );
+    cmp_ok( $product->messages->count, '==', 2, "parent has 2 messages" );
+    cmp_ok( $variant->messages->count, '==', 0, "variant has 0 messages" );
 
     cmp_ok( $self->ic6s_schema->resultset('Message')->count,
         '==', 3, "3 Message rows" );
 
-    cmp_ok( $self->ic6s_schema->resultset('ProductReview')->count,
+    cmp_ok( $self->ic6s_schema->resultset('ProductMessage')->count,
         '==', 2, "2 ProductReview rows" );
 
+    throws_ok { $variant->set_reviews() }
+    qr/set_reviews needs a list of objects or hashrefs/,
+      "set_reviews with no args throws exception";
+
+    throws_ok { $variant->add_to_reviews() }
+    qr/add_to_reviews needs an object or hashref/,
+      "add_to_reviews with no args throws exception";
+
+    throws_ok { $variant->add_to_reviews('q') }
+    qr/Bad argument supplied to add_to_reviews/,
+      "add_to_reviews with bad arg throws exception";
+
     lives_ok(
         sub {
             $result = $variant->add_to_reviews(
@@ -448,8 +605,8 @@ test 'product reviews tests' => sub {
 
     cmp_ok( $product->reviews->count,  '==', 3, "parent has 3 reviews" );
     cmp_ok( $variant->reviews->count,  '==', 3, "variant has 3 reviews" );
-    cmp_ok( $product->_reviews->count, '==', 3, "parent has 3 _reviews" );
-    cmp_ok( $variant->_reviews->count, '==', 0, "variant has 0 _reviews" );
+    cmp_ok( $product->messages->count, '==', 3, "parent has 3 messages" );
+    cmp_ok( $variant->messages->count, '==', 0, "variant has 0 messages" );
 
     cmp_ok( $self->ic6s_schema->resultset('Message')->count,
         '==', 4, "4 Message rows" );
@@ -469,10 +626,41 @@ test 'product reviews tests' => sub {
 
     cmp_ok( $product->reviews->count, '==', 3, "parent has 3 reviews" );
 
+    lives_ok {
+        $message = $self->ic6s_schema->resultset('Message')->create(
+            {
+                title   => "some message",
+                content => "the content",
+                type    => "order_comment"
+            }
+          )
+    }
+    "create an order comment";
+
+    throws_ok { $product->add_to_reviews($message) }
+    qr/cannot add message type.+to reviews/,
+      "cannot add order_comment using add_to_reviews";
+
+    lives_ok {
+        $message = $rset_message->create(
+            {
+                title   => "some message",
+                content => "the content",
+                type    => "product_review"
+            }
+          )
+    }
+    "create a review";
+
+    lives_ok { $product->add_to_reviews($message) }
+      "add review object using add_to_reviews";
+
+    cmp_ok( $product->reviews->count, '==', 4, "parent has 4 reviews" );
+
     lives_ok( sub { $product->delete }, "delete parent" );
 
     cmp_ok( $self->ic6s_schema->resultset('Message')->count,
-        '==', 1, "1 Message row" );
+        '==', 2, "2 Message rows" );
 
     # cleanup
     $self->clear_products;
